import re

def get_photo_per_user(item):
    photo_caption = re.sub('\n|"', '', item.caption.text.encode('utf-8')) if item.caption is not None else ''
    photo_comment = item.comment_count
    created_time = item.created_time
    photo_filter = item.filter
    photo_id = item.id
    photo_url = item.images.get('standard_resolution').url
    photo_like = item.like_count
    photo_link = item.link
    tags = item.tags if hasattr(item, 'tag') else ''
    item_type = item.type
    user_username = item.user.username.encode('utf-8')
    user_id = item.user.id
    photo_userliked = item.user_has_liked
    users_in_photo = item.users_in_photo

    if len(users_in_photo) > 0:
        no_users_in_photo = len(users_in_photo)
        usernames = ''
        for user in users_in_photo:
            usernames += user.user.id + ','
    else:
        no_users_in_photo = 0
        usernames = ''

    if hasattr(item, 'location'):
        location_disclosed = 1
        photo_location_id = item.location.id
        # print item.location.point
        photo_location_name = item.location.name.encode('utf-8')
        photo_location_lat = item.location.point.latitude
        photo_location_long = item.location.point.longitude

    else:
        location_disclosed = 0
        photo_location_id = ''
        photo_location_name = ''
        photo_location_lat = ''
        photo_location_long = ''


    return [user_id,
            user_username,
            photo_id,
            created_time.__str__(),
            '"' + photo_caption + '"',
            photo_filter,
            photo_link,
            photo_url,
            item_type,
            photo_like.__str__(),
            photo_comment.__str__(),
            photo_userliked.__str__(),
            tags,
            no_users_in_photo.__str__(),
            usernames,
            location_disclosed.__str__(),
            photo_location_id,
            photo_location_name,
            photo_location_lat,
            photo_location_long]



import sys
import re
from os import listdir

def split(fp, nSplit=10):
    f = open(fp, 'r')
    n = 0
    for _ in f:
        n += 1
    f.close()

    f_i = open(fp, 'r')
    i = 0
    c = 0
    for line in f_i:
        i += 1
        if i > (n / nSplit + 1) * c:
            c += 1
            print c
        f_o = open('_'.join([fp.split('.')[0], str(c)]), 'a')
        f_o.write(line.strip() + '\n')
        f_o.close()

    f_i.close()


def merge(fp):
    file = fp.split('/')[-1]
    folder = re.sub(file, '', fp)
    o = open(fp, 'a')
    for f in listdir(folder):
        if f.startswith(file):
            i = open(folder + f, 'r')
            for line in i:
                o.write(line.strip() + '\n')
            i.close()
    o.close()

# merge('/Users/cchen224/Downloads/CustomerName_clean')


if __name__ == '__main__':
    argvs = sys.argv[1:]
    fp = argvs[0]
    try:
        nSplit = argvs[1]
        split(fp, int(nSplit))
    except:
        split(fp)



import sys
import time
import traceback
import socket

import httplib2
from instagram import InstagramAPIError
from instagram import InstagramClientError
from instagram.client import InstagramAPI
import datetime

from cutils.gmail import Gmail
from cutils.progress_bar import ProgressBar
from pyAPIs.instagram.access_tokens import access_tokens


class Instagram:

    def __init__(self, job):
        self._job = job
        self._account = 1
        self._extention = ''
        self._output = ''

        if 'follower' in job.lower():
            self._extention = '.followers'
        elif 'following' in job.lower() or 'friend' in job.lower():
            self._extention = '.following'
        elif 'photo' in job.lower() or 'media' in job.lower():
            self._extention = '.media'

        self._gmail = Gmail().set_from_to()

    def set_access_token(self, i):
        self._account = i
        self._api = InstagramAPI(access_token=access_tokens[self._account])
        self._gmail = self._gmail.set_subject('AWS Instagram' + self._extention + '_' + str(i))
        return self

    def set_output(self, output):
        self._output = output
        return self

    def request(self, user_id, generator):
        c = 0
        n_retries_client = 0
        n_retries_socket = 0

        while True:
            if n_retries_client >= 10 or n_retries_socket >= 10:
                break
            try:
                items, _next = generator.next()

                if self._output == '':
                    o = open(user_id + self._extention, 'a')
                else:
                    o = open(self._output, 'a')

                c += 1
                for item in items:
                    if self._extention in ['.followers', '.following']:
                        o.write(item.id + '\n')
                    elif self._extention == '.media':
                        from get_photo_per_user import get_photo_per_user
                        o.write(','.join(get_photo_per_user(item)) + '\n')
                sys.stdout.write(' User' + user_id + ': ' + str(c) + '\r')
                sys.stdout.flush()
                o.close()
                if _next:
                    time.sleep(0.72)
                else:
                    break
            except InstagramAPIError, e:
                if str(e.status_code) == '429':
                    time.sleep(60)
                    self._gmail = self._gmail.send_message('429ExceedsLimit...')
                    self._gmail = self._gmail.send_message(datetime.datetime.now().__str__() + '\n')
                    continue
                elif str(e.status_code) == '400':
                    self._gmail = self._gmail.send_message('400NotFound...')
                    break
            except httplib2.ServerNotFoundError:
                self._gmail = self._gmail.send_message('ServerNotFoundError...')
                time.sleep(10)
                continue
            except InstagramClientError, e:
                n_retries_client += 1
                if str(e.error_message) == '402':
                    try:
                        self._gmail = self._gmail.send_message(user_id + ' ' + str(c) + '\n\n' + traceback.format_exc() + '\n\n')
                        self._gmail = self._gmail.close()
                    except:
                        pass
                time.sleep(5)
                continue
            except socket.error:
                n_retries_socket += 1
                time.sleep(5)
                continue
            except StopIteration:
                break
            except Exception:
                Gmail(0).set_from_to().set_subject('AWS Instagram' + self._extention + ' Error!')\
                    .send_message(user_id + '\nRequestError on page' + str(c) + '\n\n' + traceback.format_exc() + '\n\n')
                continue

    def loop(self, fp):
        i = open(fp, 'r')
        n = 0
        for _ in i:
            n += 1
        i.close()
        bar = ProgressBar(total=n)

        print 'Starting', '...'
        i = open(fp, 'r')
        for line in i:
            try:
                bar = bar.move().log()
                user_id = line.strip()
                self._gmail = self._gmail.send_message('User' + user_id)
                self.request(user_id,
                             {'.followers': self._api.user_followed_by(user_id=user_id, as_generator=True, max_pages=999999),
                              '.following': self._api.user_follows(user_id=user_id, as_generator=True, max_pages=999999),
                              '.media': self._api.user_recent_media(user_id=user_id, as_generator=True, max_pages=60)
                              }.get(self._extention))
                self._gmail = self._gmail.send_message('Done!\n')
            except KeyboardInterrupt:
                Gmail(0).set_from_to().set_subject('AWS Instagram' + self._extention + ' Stopped!')\
                    .send_message(user_id + '@access_token ' + self._account)
                i.close()
                bar.close()
                return False
        self._gmail = self._gmail.send_message('\n' + fp + ' Done.\n')
        self._gmail = self._gmail.close()
        i.close()
        bar.close()
        return True

    def test(self, user_id):
        self.request(user_id,
                     {'.followers': self._api.user_followed_by(user_id=user_id, as_generator=True, max_pages=999999),
                      '.following': self._api.user_follows(user_id=user_id, as_generator=True, max_pages=999999),
                      '.media': self._api.user_recent_media(user_id=user_id, as_generator=True, max_pages=60)
                      }.get(self._extention))


# if __name__ == '__main__':
#     argvs = sys.argv[1:]
#     job_name = argvs[0]
#     filepath = argvs[1]
#     server = int(argvs[2])
#     ins = Instagram(job_name).set_access_token(server).loop(filepath)


# Instagram('followers').set_access_token(19).test('294211877')


import re


def parse_text(js_tweet_text_container,
                is_remove_url=True,
                is_remove_mentions=False,
                is_remove_hashtags=False,
                is_remove_cashtags=False,
                is_remove_emojis=True
               ):

    hashtags = []
    cashtags = []
    mentions = []
    emojis = []

    try:
        a_hrefs = js_tweet_text_container.p(['a', 'img'])
        for s in a_hrefs:
            if s.has_attr('data-expanded-url'):
                if is_remove_url:
                    s.extract()
            elif s.has_attr('data-query-source'):
                if s.attrs['data-query-source'] == 'cashtag_click':
                    cashtags.append(s.text.strip())
                    if is_remove_cashtags:
                        s.extract()
                elif s.attrs['data-query-source'] == 'hashtag_click':
                    hashtags.append(s.text.strip())
                    if is_remove_hashtags:
                        s.extract()
            elif s.has_attr('data-mentioned-user-id'):
                mentions.append(s.attrs['data-mentioned-user-id'])
                if is_remove_mentions:
                    s.extract()
            elif s.has_attr('class') and 'Emoji--forText' in s.attrs['class']:
                emojis.append('_'.join(s.attrs['title'].split()))
                if is_remove_emojis:
                    s.extract()
    except TypeError:
        pass

    text = js_tweet_text_container.text
    text = re.sub(',|\n', ' ', text)
    text = '"' + re.sub(' +', ' ', text).strip() + '"'

    hashtags = '|'.join(hashtags)
    cashtags = '|'.join(cashtags)
    mentions = '|'.join(mentions)
    emojis   = '|'.join(emojis)

    return {'text': text, 'hashtags': hashtags, 'cashtags': cashtags, 'mentions': mentions, 'emojis': emojis}



def parse_footer(stream_item_footer):
    retweets = stream_item_footer.find('div', attrs={'title': 'Retweet'}).text
    retweets = re.sub('[^0-9]', '', retweets)
    if retweets == '': retweets = u'0'

    likes = stream_item_footer.find('div', attrs={'title': 'Like'}).text
    likes = re.sub('[^0-9]', '', likes)
    if likes == '': likes = u'0'


    return {'retweets': retweets, 'likes': likes}


def parse_fixer(js_tweet_details_fixer):
    time = js_tweet_details_fixer.find('div', class_='client-and-actions').text.strip()

    stats = js_tweet_details_fixer.find('div', class_='js-tweet-stats-container tweet-stats-container ')
    try:
        retweets = stats.find('a', class_='request-retweeted-popup').text
        retweets = re.sub('[^0-9]', '', retweets)
    except AttributeError:
        retweets = '0'

    try:
        likes = stats.find('a', class_='request-favorited-popup').text
        likes = re.sub('[^0-9]', '', likes)
    except AttributeError:
        likes = '0'

    return {'time': time, 'retweets': retweets, 'likes': likes}


import re
import sys
import traceback

import requests
from bs4 import BeautifulSoup

from gmail import Gmail


def get_user_info(user_id):

    url = 'https://twitter.com/' + str(user_id)
    html = requests.request('GET', url).text.encode('ascii', 'ignore')
    soup = BeautifulSoup(html, 'html.parser')
    out = dict()

    profile_navigation_soup = soup.find('div', class_='ProfileNav')
    try:
        out['tweets'] = profile_navigation_soup.find('li', class_='ProfileNav-item ProfileNav-item--tweets is-active').a.attrs['title']
    except AttributeError:
        out['tweets'] = str(0)
    try:
        out['following'] = profile_navigation_soup.find('li', class_='ProfileNav-item ProfileNav-item--following').a.attrs['title']
    except AttributeError:
        out['following'] = str(0)
    try:
        out['followers'] = profile_navigation_soup.find('li', class_='ProfileNav-item ProfileNav-item--followers').a.attrs['title']
    except AttributeError:
        out['followers'] = str(0)
    try:
        out['likes'] = profile_navigation_soup.find('li', class_='ProfileNav-item ProfileNav-item--favorites').a.attrs['title']
    except AttributeError:
        out['likes'] = str(0)

    out['tweets'] = re.sub(' Tweets| Tweet|,', '', out['tweets'])
    out['following'] = re.sub(' Following|,', '', out['following'])
    out['followers'] = re.sub(' Followers| Follower|,', '', out['followers'])
    out['likes'] = re.sub(' Likes| Like|,', '', out['likes'])


    profile_header_soup = soup.find('div', class_='ProfileHeaderCard')
    try:
        out['bio'] = profile_header_soup.find('p', class_='ProfileHeaderCard-bio u-dir').text.strip()
        out['bio'] = re.sub('"|\n', '', out['bio'])
    except AttributeError:
        out['bio'] = ''
    try:
        out['location'] = profile_header_soup.find('div', class_='ProfileHeaderCard-location').text.strip()
    except AttributeError:
        out['location'] = ''
    try:
        out['join_date'] = profile_header_soup.find('div', class_='ProfileHeaderCard-joinDate').text.strip()
    except AttributeError:
        out['join_date'] = ''
    try:
        out['is_verified'] = profile_header_soup.h1.span.text.strip()
        if out['is_verified'] == 'Verified account':
            out['is_verified'] = 'yes'
        else:
            out['is_verified'] = 'no'
    except AttributeError:
        out['is_verified'] = 'no'

    return out

if __name__ == '__main__':
    argvs = sys.argv[1:]
    input = argvs[0]
    output = input + '.csv'
    gmail = Gmail(0).set_from_to().set_subject('AWS_CustomerNameClean')
    print 'Starting...'
    f = open(input, 'r')
    o = open(output, 'a')
    i = 0
    for line in f:
        i += 1
        if i % 1000 == 0:
            print i,
        user = line.strip()
        info = get_user_info(user)
        try:
            # screen_name,is_verified,bio,location,join_date,tweets,following,followers,likes
            o.write(','.join([user, info['is_verified'],
                          '"' + info['bio'] + '"', '"' + info['location'] + '"', '"' + info['join_date'] + '"',
                          info['tweets'], info['following'], info['followers'], info['likes']]).encode('ascii', 'ignore'))
            o.write('\n')
        except:
            gmail = gmail.send_message(input + ': user ' + user + '\n' + traceback.format_exc())
    f.close()
    o.close()
    gmail = gmail.send_message(input + '\nDone')





import argparse
import base64
import datetime
import re
import sys
from email.mime.text import MIMEText

from googleapiclient.discovery import build
from httplib2 import Http
from oauth2client import client
from oauth2client import file
from oauth2client import tools
import pkg_resources


class Gmail:

    PACKAGE_NAME = 'cutils'
    SCOPES = 'https://mail.google.com/'
    CLIENT_SECRET_FILE = pkg_resources.resource_filename(PACKAGE_NAME, 'fattywhitysmarty.json')
    APPLICATION_NAME = 'Notifier'

    _message_text = ''

    def __init__(self, minDuration=3600*24):
        self._flags = argparse.ArgumentParser(parents=[tools.argparser]).parse_args([])
        self._create_at = datetime.datetime.now()
        self._min_duration = minDuration
        self._subject = 'AWS Status'

    def get_credentials(self):
        credential_file = pkg_resources.resource_filename(self.PACKAGE_NAME, re.sub('@.+$', '', self._sender) + '.credentials')
        store = file.Storage(credential_file)
        credentials = store.get()
        if not credentials or credentials.invalid:
            flow = client.flow_from_clientsecrets(self.CLIENT_SECRET_FILE, self.SCOPES)
            flow.user_agent = self.APPLICATION_NAME
            if self._flags:
                credentials = tools.run_flow(flow, store, self._flags)
            else:  # Needed only for compatability with Python 2.6
                credentials = tools.run(flow, store)
                # print 'Storing credentials to ' + credential_path
        return credentials

    @staticmethod
    def create_message(sender, to, subject, message_text):
        message = MIMEText(message_text)
        message['to'] = to
        message['from'] = sender
        message['subject'] = subject
        return {'raw': base64.b64encode(message.as_string())}

    def send_message(self, message_text):
        self._credentials = self.get_credentials()
        self._service = build('gmail', 'v1', http=self._credentials.authorize(Http()))
        self._message_text += message_text + ' '
        if (datetime.datetime.now() - self._create_at).seconds <= self._min_duration:
            return self
        else:
            message = self.create_message(self._sender + '@gmail.com', self._receiver, self._subject, self._message_text)
            self._service.users().messages().send(userId='me', body=message).execute()
            self._message_text = ''
            self._create_at = datetime.datetime.now()
            return self

    def close(self):
        message = self.create_message(self._sender + '@gmail.com', self._receiver, self._subject, self._message_text)
        self._service.users().messages().send(userId='me', body=message).execute()
        self._message_text = ''
        self._create_at = datetime.datetime.now()
        return self

    def set_from_to(self, sender='fattywhitysmarty', receiver='fattywhitysmarty'):
        if '@' not in sender:
            self._sender = sender + '@gmail.com'
        else:
            self._sender = sender
        if '@' not in receiver:
            self._receiver = receiver + '@gmail.com'
        else:
            self._receiver = receiver
        return self

    def set_subject(self, subject):
        self._subject = subject
        return self

    def set_min_duration(self, minDuration):
        self._min_duration = minDuration
        return self

# test
# g = Gmail(minDuration=10).set_from_to().set_subject('test')
# g = g.send_message('a')
# g = g.close()





from cutils import Gmail, ProgressBar
from webparser_tweet import parse_tweet
import random
import re
import sys
import time
import traceback

class TwitterCrawler:

    def __init__(self):
        self._gmail = Gmail().set_from_to().set_subject('AWS TweetContent Status')


    def crawl(self, input, output):
        total = 0
        f_scan = open(input, 'r')
        for _ in f_scan:
            total += 1
        f_scan.close()
        self._bar = ProgressBar(total=total)

        f = open(input, 'r')
        o = open(output, 'a')
        i = 0
        for line in f:
            tokens = line.split(',')
            tid = tokens[0]
            uid = tokens[1]
            screen_name = re.sub('\'', '"', tokens[3])
            time_date = re.sub('\'', '"', tokens[2])
            try:
                i += 1
                if i % 10000 == 0:
                    print i, 'sleeping for a sec.'
                    time.sleep(random.uniform(4, 9))

                info = parse_tweet(uid, tid)
                if info['has_result'] is True:
                    o.write(','.join([uid, screen_name.strip(), tid, time_date, info['text'],
                                      info['hashtags'], info['cashtags'], info['mentions'], info['emojis'],
                                      info['retweets'], info['likes'],
                                      info['n_uid'], info['n_tid']]))
                    o.write('\n')
                elif info['has_result'] == 'ConnectionError':
                    self._gmail = self._gmail.send_message(output + '\n' + uid + ' ' + tid + ' Connection Error.')
                    break
            except:
                self._gmail = self._gmail.send_message(input + '\n' + uid + ' ' + tid + '\n' + traceback.format_exc())

            self._bar.move()
            self._bar.log()
        f.close()
        o.close()
        self._bar.close()


import sys


class ProgressBar:
    def __init__(self, count=0, total=0, width=50):
        self.count = count
        self.total = total
        self.width = width
        self.digit = len(str(self.total))
        self.outof = '{0:>' + str(self.digit + 1) + '} / {1:<' + str(self.digit) + '}: '

    def move(self):
        self.count += 1
        return self

    def log(self, s=''):
        sys.stdout.write(' ' * (self.width + 9) + '\r')
        sys.stdout.flush()
        if s != '':
            print s
        progress = self.width * self.count / self.total
        sys.stdout.write(' ' * 20 + self.outof.format(self.count, self.total))
        sys.stdout.write('#' * progress + '-' * (self.width - progress))
        sys.stdout.write('  {}%'.format(round(float(self.count) / self.total * 100, 2)) + '\r')
        sys.stdout.flush()
        return self

    def close(self):
        sys.stdout.write('\n')
        sys.stdout.flush()
        return self


# import time
# bar = ProgressBar(total=1901)
# for i in range(1901):
#     bar = bar.move().log()
#     time.sleep(0.01)
# bar.close()



import time
import random

import requests
from bs4 import BeautifulSoup

from webparser_utility import parse_text, parse_fixer


def parse_tweet(uid, tid):
    out = {'n_uid': '', 'n_tid': '', 'has_result': True}

    url = 'https://twitter.com/' + uid + '/status/' + tid
    try:
        html = requests.request('GET', url).text.encode('ascii', 'ignore')
    except requests.ConnectionError:
        time.sleep(60)
        print 'Connection error, sleeping'
        try:
            html = requests.request('GET', url).text.encode('ascii', 'ignore')
        except requests.ConnectionError:
            f_out = open('stop', 'a')
            f_out.write(uid + ',' + tid + '\n')
            out['has_result'] = 'ConnectionError'
            f_out.close()
            return out
    soup = BeautifulSoup(html, 'html.parser')

    for fnc in [is_account_not_suspended(soup), is_content_not_protected(soup), is_page_exists(soup)]:
        out['has_result'] = fnc
        if out['has_result'] is False:
            return out


    # PermalinkOverlay
    tweet_inner_soup = soup.find('div', attrs={"data-tweet-id": tid})
    if tweet_inner_soup is None:
        try:
            tweet_inner_soup = soup.find('div', class_='permalink-inner permalink-tweet-container')
            out['n_uid'] = tweet_inner_soup.div.attrs['data-user-id']
            out['n_tid'] = tweet_inner_soup.div.attrs['data-tweet-id']
        except AttributeError:
            print '404, sleeping'
            from gmail import Gmail
            Gmail(0).set_from_to().set_subject('AWS_TweetContent').send_message(' '.join([uid, tid]) + soup.__str__())
            time.sleep(random.uniform(7, 13))
            return parse_tweet(uid, tid)
    out.update(parse_text(tweet_inner_soup.find('div', class_="js-tweet-text-container")))
    out.update(parse_fixer(tweet_inner_soup.find('div', class_='js-tweet-details-fixer tweet-details-fixer')))

    return out


def is_page_exists(soup):
    try:
        content = soup.find('div', class_='body-content').h1.text.strip()
        if content == 'Sorry, that page doesnt exist!':
            return False
    except AttributeError:
        return True


def is_content_not_protected(soup):
    try:
        content = soup.find('div', class_='message-inside').span.text.strip()
        if content == 'Sorry, you are not authorized to see this status.':
            return False
    except AttributeError:
        return True


def is_account_not_suspended(soup):
    try:
        content = soup.find('div', class_='flex-module error-page clearfix').h1.text.strip()
        if content == 'Account suspended':
            return False
    except AttributeError:
        return True



from instagram import InstagramAPI, client, oauth2, InstagramAPIError
from instagram.bind import InstagramAPIError
import csv
from time import sleep
from datetime import datetime
import os
import sys



# access_token = '937212526.80bcce7.4 1f9aea947504150b418c4d60d159929'
#access_token = '937212526.d2aec0b.24b8d6c3940643a592b5c72512e42d4c'
#access_token = '937212526.5f06f7a.90966e83f9dd43eeb1fac3d135abed24'
#access_token = '937212526.35519fe.91c4ebdf62444231b36df3066a9a62e1'
#access_token = '937212526.d356296.1ec199e742b540b69017d1fdc0838404'
#access_token = '937280448.63a8f6e.f08c72c5df0a46099da1c17b2022b4ef'
#access_token = '937280448.09bccc4.d4c901f227464006a60b7367f92c023d'
#access_token = '937280448.948a325.347e49226f974a718765c8611720f780'
#access_token = '937280448.197d7e4.0ba69739bf02428782546dbdacc9337f'
#access_token = '937280448.5182a49.11af1a709c9c4fa7b9c96a4f6bb38ac7'
#access_token = '937358110.64ee73f.9ea27205a93d485a932fbbd771122574'
#access_token = '937358110.a358ce4.de1b7e677c86409ca93916e972c7d2d0'
#access_token = '937358110.7de18ec.01ef8f2c7591467b99285e0f8abb0b20'
#access_token = '937358110.38e9503.edb2757a445e48bb9cbf35a90ac60ede'
#access_token = '937358110.7781482.f19e57cac4cd455b8c3d68ed1c3d1462'
# access_token = '938075294.a594a2a.0924280c580147b5b43ba715a3f90052'
#access_token = '938075294.8576c14.dbd08371297f4956bc3f9142b4ba5944'
#access_token = '938075294.93b5a61.a03807e6e0c848e1adda4722f5aafc6d'
#access_token = '938075294.71ab8b9.97fbee0735a64f8c90dcbaeca7457f7e'
#access_token = '938075294.938bcc8.09a1241cf00e4a6fb899207704749a17'

#new
# access_token = '616474981.003c66c.42dfbdb746d149469331f3acd0300455'
#access_token=616474981.ed555dc.8e8e521b689e4bbbb58c611d8fb628dd
#access_token=616474981.a822b83.c3af254747c849ee8b6c1469e0bd0186
#access_token=616474981.86f3a3d.b59f6439980049b2b3383bda9f2f5c5d
#access_token=616474981.bfe25b6.3a90d1a792b142dfb70dce8e4b606c34

#accessToken = sys.argv[1]
# filetoread = sys.argv[1]
# dir = sys.argv[2]
# errorfile = sys.argv[3]

api = InstagramAPI(access_token=access_token)

def GetPhotoByUsername(uid):
     try:
        for recent_media in api.user_recent_media(user_id=uid, as_generator=True, max_pages=60): #only one page
            global j
            j += len(recent_media[0])
            for item in recent_media[0]:
                if item.caption is not None: #can be no caption
                    photo_caption = item.caption.text.encode('utf-8')
                else:
                    photo_caption = ''
                # print photo_caption
                photo_comment = item.comment_count
                created_time = item.created_time
                photo_filter = item.filter
                photo_id = item.id
                photo_url = item.images.get('standard_resolution').url
                photo_like = item.like_count
                photo_link = item.link
                if hasattr(item, 'tag'): #can be no caption
                    tags = item.tags
                else:
                    tags = ''
                item_type = item.type
                user_username = item.user.username.encode('utf-8')
                user_id = item.user.id
                photo_userliked = item.user_has_liked
                users_in_photo = item.users_in_photo
                if len(users_in_photo) > 0:
                    no_users_in_photo = len(users_in_photo)
                    usernames = ''
                    for user in users_in_photo:
                        usernames += user.user.id + ','
                else:
                    no_users_in_photo = 0
                    usernames = ''

                if hasattr(item, 'location'):
                    location_disclosed = 1
                    photo_location_id = item.location.id
                    # print item.location.point
                    photo_location_name = item.location.name.encode('utf-8')
                    photo_location_lat = item.location.point.latitude
                    photo_location_long = item.location.point.longitude

                else:
                    location_disclosed = 0
                    photo_location_id = ''
                    photo_location_name = ''
                    photo_location_lat = ''
                    photo_location_long = ''

                writer.writerow([user_id,user_username,photo_id,created_time,photo_caption,photo_filter,photo_link,photo_url,item_type,photo_like,photo_comment,photo_userliked,tags,no_users_in_photo,usernames,location_disclosed,photo_location_id,photo_location_name,photo_location_lat,photo_location_long])
     except Exception as e:
         print e,
         errorwriter.writerow([uid,str(datetime.now())])


uid = '628056564'
uid = '9273671' #shulei test

lines = [line.rstrip('\n') for line in open('/Users/hyheng/Dropbox/Instagram-projects/ids_merge_sample.txt')]


index = 0
j = 0

# with open('/Users/hyheng/Dropbox/Instagram-projects/merge de-outlier-sample.csv', 'rb') as fin:
with open('/Users/hyheng/Dropbox/Instagram-projects/data/test_csv_res.csv', 'a') as fout:
    with open('/Users/hyheng/Dropbox/Instagram-projects/data/test_csv_res[error].csv', 'a') as ferror:

        # reader = csv.reader(fin)
        writer = csv.writer(fout)
        errorwriter = csv.writer(ferror)

        # for row in reader:
        #     uid = row[0]
        for line in lines[index:]:
            GetPhotoByUsername(line)
            # print line
            # j += 1
            if j % 20 is 0:
                res = j/20
            else:
                res = j/20 + 1
            print res
            if res >= 4800:
                print 'sleep - ' + str(datetime.now())
                sleep(3300)
                j = 0


